@@ -1,25 +1,27 @@
 #ifndef __PINYIN_CONVERSION_HELPER_H__
 #define __PINYIN_CONVERSION_HELPER_H__
 
-#include "Alphabet/Alphabet.h"
 #include "Alphabet/AlphIO.h"
-#include "LanguageModelling/LanguageModel.h"
+#include "Alphabet/Alphabet.h"
 #include "ConversionHelper.h"
 #include "DasherNode.h"
+#include "LanguageModelling/LanguageModel.h"
+#include "PinyinParser.h"
+
+#include <string>
 
 //both of these start from 0
 typedef int HZIDX; 
 typedef int CANDIDX; 
 
-
 class CPinYinConversionHelper : public CConversionHelper {
  public:
 
-  CPinYinConversionHelper(Dasher::CEventHandler *pEventHandler,  CSettingsStore *pSettingsStore, Dasher::CAlphIO *pAlphIO);
+  CPinYinConversionHelper(Dasher::CEventHandler *pEventHandler,  CSettingsStore *pSettingsStore, Dasher::CAlphIO *pAlphIO, const std::string &strAlphabetPath);
   
   virtual bool Convert(const std::string &strSource, SCENode ** pRoot, int * childCount, int CMid);
 
-  virtual void AssignSizes(SCENode * pStart, Dasher::CLanguageModel::Context context , long normalization, int uniform, int iNChildren);
+  virtual void AssignSizes(SCENode **pStart, Dasher::CLanguageModel::Context context , long normalization, int uniform, int iNChildren);
 
   virtual void GetProbs(Dasher::CLanguageModel::Context context, std::vector < unsigned int >&Probs, int norm);
 
@@ -42,8 +44,8 @@ class CPinYinConversionHelper : public CConversionHelper {
 
  private:
      
-  void TrainChPPM();
-  void ProcessFile(int index);
+  void TrainChPPM(CSettingsStore *pSettingsStore);
+  void ProcessFile(CSettingsStore *pSettingsStore, int index);
 
   CLanguageModel *m_pLanguageModel;     // pointer to the language model
   CAlphabet *m_pAlphabet;        // pointer to the alphabet
@@ -79,6 +81,10 @@ class CPinYinConversionHelper : public CConversionHelper {
                            //CalculateScore
 
 
+  CPinyinParser *pParser;
+
+  int m_iPriorityScale;
+
 };
 
 #endif
