@@ -2,6 +2,7 @@
 
 #include <glib/gi18n.h>
 #include <libintl.h>
+#include <cstring>
 
 #include "../Common/Common.h"
 #include "DasherTypes.h"
@@ -213,8 +214,14 @@ static void dasher_preferences_dialogue_init(DasherPreferencesDialogue *pDasherC
 }
 
 static void dasher_preferences_dialogue_destroy(GObject *pObject) {
+  DasherPreferencesDialogue *pSelf = (DasherPreferencesDialogue *)pObject;
+  DasherPreferencesDialoguePrivate *pPrivate = (DasherPreferencesDialoguePrivate *)(pSelf->private_data);
+
+  g_object_unref(pPrivate->pGladeXML);
+
   // FIXME - I think we need to chain up through the finalize methods
   // of the parent classes here...
+  delete pPrivate;
 }
 
 // Public methods
@@ -232,7 +239,7 @@ DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidge
   pPrivate->pEditor = pEditor;
   pPrivate->pAppSettings = pAppSettings;
 
-  pPrivate->pGladeXML = pGladeWidgets;
+  pPrivate->pGladeXML = (GladeXML *)g_object_ref(pGladeWidgets);
 
   pPrivate->pPreferencesWindow = glade_xml_get_widget(pGladeWidgets, "preferences");
 
@@ -248,6 +255,12 @@ DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidge
   dasher_preferences_dialogue_refresh_widget(pDasherControl, -1);
   dasher_preferences_dialogue_update_special(pDasherControl, -1);
 
+#ifdef WITH_MAEMO
+#ifndef WITH_MAEMOFULLSCREEN
+  gtk_widget_hide(glade_xml_get_widget(pGladeWidgets, "displaysizebox"));
+#endif
+#endif
+
 #ifndef JAPANESE
   gtk_widget_hide(glade_xml_get_widget(pGladeWidgets, "radiobutton9"));
 #endif
@@ -322,6 +335,7 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
   gtk_tree_model_get(pModel, pIter, 2, &szComparison, -1);
 
   if(!strcmp(szTarget, szComparison)) {
+    free(szComparison);
     // Todo: set selection here?
     gtk_tree_view_set_cursor((GtkTreeView *)pPointers[1], pPath, NULL, false);
 
@@ -329,6 +343,8 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
 
     return true;
   }
+
+  free(szComparison);
   
   return false;
 }
@@ -440,7 +456,9 @@ void dasher_preferences_dialogue_populate_list(DasherPreferencesDialogue *pSelf,
 
     // This is potentially horrible - maybe rethink in the future;
     gtk_list_store_set(pStore, &oIter, 0, iParameter, 1, pHelper, 2, szName, 3, szName, 4, pHelperWindow, 5, pHelperWindowRef, -1);
- 
+
+    delete[] szName;
+
     if(!strcmp(szCurrentFilter, szCurrentValue)) {
       gtk_tree_selection_select_iter(pSelection, &oIter);
       if(pHelper) {
@@ -470,7 +488,8 @@ extern "C" void on_list_selection(GtkTreeSelection *pSelection, gpointer pUserDa
     gtk_tree_model_get(pModel, &oIter, 0, &iParameter, 1, &pHelper, 2, &szValue, 4, &pHelperWindow, 5, &pHelperWindowRef, -1);
     
     dasher_app_settings_set_string(pPrivate->pAppSettings, iParameter, szValue);
-    
+    free(szValue);
+
     if(pHelper) {
       gtk_widget_set_sensitive(GTK_WIDGET(pHelper), pHelperWindow != NULL);
       *((GtkWidget **)pHelperWindowRef) = (GtkWidget *)pHelperWindow;
@@ -944,7 +963,7 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
   
   pPrivate->pListStore = gtk_list_store_new(ACTIONS_N_COLUMNS, G_TYPE_INT, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
-  GtkTreeIter oIter;
+//  GtkTreeIter oIter;
 
   // TODO: Reimplement this
 
