@@ -63,9 +63,11 @@ CDasherWindow::CDasherWindow() {
   wc.m_wc.hCursor = LoadCursor(NULL, IDC_ARROW);
   wc.m_wc.hbrBackground = (HBRUSH) (COLOR_WINDOW); 
  #ifndef _WIN32_WCE
-  wc.m_wc.lpszMenuName = (LPCTSTR) IDC_DASHER;
+ // wc.m_wc.lpszMenuName = (LPCTSTR) IDC_DASHER;
   wc.m_wc.hIconSm = m_hIconSm;
 #endif
+
+  m_hMenu = LoadMenu(WinHelper::hInstApp, (LPCTSTR) IDC_DASHER);
 }
 
 HWND CDasherWindow::Create() {
@@ -81,14 +83,20 @@ HWND CDasherWindow::Create() {
   HWND hWnd;
 
 #ifndef _WIN32_WCE
-  if((iStyle == APP_STYLE_COMPOSE) || (iStyle == APP_STYLE_DIRECT))
+  if((iStyle == APP_STYLE_COMPOSE) || (iStyle == APP_STYLE_DIRECT)) {
     hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN,  WS_EX_NOACTIVATE | WS_EX_APPWINDOW | WS_EX_TOPMOST);
-  else
+    ::SetMenu(hWnd, NULL);
+  }
+  else {
     hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN);
+    ::SetMenu(hWnd, m_hMenu);
+  }
 #else
   hWnd = CWindowImpl<CDasherWindow, CWindow, CWinTraits<WS_CLIPCHILDREN | WS_CLIPSIBLINGS> >::Create(NULL);
 #endif
 
+
+
   // Create Widgets
   m_pDasher = new CDasher(hWnd);
 
@@ -421,9 +429,7 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
       m_pEdit->SaveAs();
     return 0;
   case ID_IMPORT_TRAINFILE:
-    // TODO: Fix dummy arguments
-	  // Game temp comment for compiling
-    //m_pDasher->TrainFile(m_pEdit->Import(),0,0);
+    m_pDasher->ImportTrainingText(m_pEdit->Import());
     return 0;
   default:
     return DefWindowProc(message, wParam, lParam);
@@ -532,10 +538,10 @@ LRESULT CDasherWindow::OnClose(UINT message, WPARAM wParam, LPARAM lParam, BOOL&
 LRESULT CDasherWindow::OnSize(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled) {
   if(wParam == SIZE_MINIMIZED)
     return 0;
-  
-  m_pToolbar->Resize();
-//  m_pSlidebar->Resize();
-  
+
+  if(m_pToolbar)
+    m_pToolbar->Resize();
+
   Layout();
   
   return 0;
@@ -574,10 +580,12 @@ void CDasherWindow::Layout() {
   if((iStyle == APP_STYLE_COMPOSE) || (iStyle == APP_STYLE_DIRECT)) {
     SetWindowLong(GWL_EXSTYLE, GetWindowLong(GWL_EXSTYLE) | WS_EX_NOACTIVATE | WS_EX_APPWINDOW);
     SetWindowPos(HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+	SetMenu(NULL);
   }
   else {
     SetWindowLong(GWL_EXSTYLE, GetWindowLong(GWL_EXSTYLE) & !WS_EX_NOACTIVATE);
     SetWindowPos(HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+	SetMenu(m_hMenu);
   }
 #endif
 
@@ -606,9 +614,15 @@ void CDasherWindow::Layout() {
   else
     SpeedAlphabetHeight = 0;
 
-  int GameGroupHeight = m_pGameGroup->GetHeight();
-  int GameGroupWidth = m_pGameGroup->GetWidth();
-  int GameLabelHeight = m_pGameGroup->GetLabelHeight();
+  int GameGroupHeight = 0;
+  int GameGroupWidth = 0;
+  int GameLabelHeight = 0;
+
+  if(m_pGameGroup) {
+    GameGroupHeight = m_pGameGroup->GetHeight();
+    GameGroupWidth = m_pGameGroup->GetWidth();
+    GameLabelHeight = m_pGameGroup->GetLabelHeight();
+  }
 
   int MaxCanvas = Height - SpeedAlphabetHeight*2;
   int CurY = ToolbarHeight;
