@@ -19,7 +19,7 @@ using namespace std;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -29,11 +29,13 @@ static char THIS_FILE[] = __FILE__;
 
 /////////////////////////////////////////////////////////////////////////////
 
-CScreen::CScreen(HDC hdc, Dasher::screenint iWidth, Dasher::screenint iHeight)
+CScreen::CScreen(HDC hdc, HWND hWnd, Dasher::screenint iWidth, Dasher::screenint iHeight)
 :CDasherScreen(iWidth, iHeight), m_hdc(hdc) {
   // set up the off-screen buffers
   // HDC hdc = GetDC(mainwindow);
 
+  m_hWnd = hWnd;
+
   // Create a memory device context compatible with the screen
   m_hDCBufferBackground = CreateCompatibleDC(hdc);      // one for rectangles
   m_hbmBitBackground = CreateCompatibleBitmap(hdc, m_iWidth, m_iHeight);
@@ -88,7 +90,9 @@ CScreen::~CScreen() {
 /////////////////////////////////////////////////////////////////////////////
 
 void CScreen::SetInterface(CDasherInterfaceBase *DasherInterface) {
+#ifndef _WIN32_WCE
   DASHER_ASSERT_VALIDPTR_RW(DasherInterface);
+#endif
 
  // CDasherScreen::SetInterface(DasherInterface);
 
